APICacheDBHelper class abstract

Implementers

Constructors

APICacheDBHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

conditionalQuery(String table, String where, String searchString) → Future<List<Map<String, dynamic>>>
customUpdate(String table, CacheDBBaseModel model, {String? columnName, String? columnValue}) → Future<int>
delete(String table, String columnName, String columnValue) → Future<int>
deleteAll(String table) → Future<int>
init() → Future<void>
insert(String table, CacheDBBaseModel model) → Future<int>
onCreate(Database db, int version) → void
onUpgrade(Database db, int oldVersion, int version) → void
query(String table) → Future<List<Map<String, dynamic>>>
rawQuery(String sql) → Future<List<Map<String, dynamic>>>
update(String table, CacheDBBaseModel model, {String? columnName}) → Future<int>